![astromet.py](https://github.com/zpenoyre/astromet.py/blob/master/astrometlogo.jpeg "text")

A simple python package for generating astrometric tracks of single stars and the center of light of unresolved binaries, blended and lensed systems. Includes a close emulation of Gaia's astrometric fitting pipeline.

https://astrometpy.readthedocs.io/en/latest/

**pip install astromet**

Still in development, functional but may occasional bugs or future changes. Get in touch with issues/suggestions.

Requires
- numpy
- astropy
- scipy
- matplotlib (for notebooks)

also - if you like astromet but wish it was faster, try the GPU optimized [jaxtromet.py](https://github.com/maja-jablonska/jaxtromet.py) made by [Maja Jabłońska](https://github.com/maja-jablonska) (who also made our logo!)
